# coding: utf-8

from _manage_basic import _manage_basic_code
from _manage_admin import _manage_admin_code
